summaryrefslogtreecommitdiff
path: root/examples/ping.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/ping.py')
-rwxr-xr-xexamples/ping.py16
1 files changed, 8 insertions, 8 deletions
diff --git a/examples/ping.py b/examples/ping.py
index 1a1c2e94..b079c41a 100755
--- a/examples/ping.py
+++ b/examples/ping.py
@@ -2,9 +2,9 @@
# -*- coding: utf-8 -*-
"""
SleekXMPP: The Sleek XMPP Library
Copyright (C) 2010 Nathanael C. Fritz
- This file is part of SleekXMPP.
+ This file is part of Slixmpp.
See the file LICENSE for copying permission.
"""
@@ -14,28 +14,28 @@ import logging
import getpass
from optparse import OptionParser
-import sleekxmpp
+import slixmpp
# Python versions before 3.0 do not use UTF-8 encoding
# by default. To ensure that Unicode is handled properly
# throughout SleekXMPP, we will set the default encoding
# ourselves to UTF-8.
if sys.version_info < (3, 0):
- from sleekxmpp.util.misc_ops import setdefaultencoding
+ from slixmpp.util.misc_ops import setdefaultencoding
setdefaultencoding('utf8')
else:
raw_input = input
-class PingTest(sleekxmpp.ClientXMPP):
+class PingTest(slixmpp.ClientXMPP):
"""
A simple SleekXMPP bot that will send a ping request
to a given JID.
"""
def __init__(self, jid, password, pingjid):
- sleekxmpp.ClientXMPP.__init__(self, jid, password)
+ slixmpp.ClientXMPP.__init__(self, jid, password)
if pingjid is None:
pingjid = self.boundjid.bare
self.pingjid = pingjid
@@ -2,9 +2,9 @@
# -*- coding: utf-8 -*-
"""
- SleekXMPP: The Sleek XMPP Library
+ Slixmpp: The Slick XMPP Library
Copyright (C) 2010 Nathanael C. Fritz
@@ -14,28 +14,28 @@ import logging
# Python versions before 3.0 do not use UTF-8 encoding
# by default. To ensure that Unicode is handled properly
-# throughout SleekXMPP, we will set the default encoding
+# throughout Slixmpp, we will set the default encoding
# ourselves to UTF-8.
if sys.version_info < (3, 0):
@@ -14,28 +14,28 @@ import logging
"""
- A simple SleekXMPP bot that will send a ping request
+ A simple Slixmpp bot that will send a ping request
to a given JID.
"""